==> kvpnc_0.8.orig.tar.gz: kvpnc-0.8/src/logviewerdialog.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef LogViewerDialog_H
#define LogViewerDialog_H

#include "logviewerdialogbase.h"
#include <kdialogbase.h>
#include <qstring.h>

/**
@author Christoph Thielecke
*/
class LogViewerDialog : public KDialogBase
{
	Q_OBJECT
public:
	LogViewerDialog(QWidget *parent, const QString& caption);

	~LogViewerDialog();

public slots:
	void accept();

private:
	LogViewerDialogBase *main;
};

#endif

==> kvpnc_0.8.5.1.orig.tar.gz: kvpnc-0.8.5.1/src/logviewerdialog.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef LogViewerDialog_H
#define LogViewerDialog_H

#include "logviewerdialogbase.h"
#include <kdialogbase.h>
#include <qstring.h>
#include "kvpncconfig.h"
#include <qapplication.h>

/**
@author Christoph Thielecke
*/
class LogViewerDialog : public KDialogBase
{
	Q_OBJECT
public:
	LogViewerDialog(QWidget *parent,QApplication *app, KVpncConfig *GlobalConfig, const QString& caption);

	~LogViewerDialog();

public slots:
	void accept();

private:
	LogViewerDialogBase *main;
	KVpncConfig *GlobalConfig;
	QApplication *app;
};

#endif
